pub struct Static<T: Indexable> { /* private fields */ }Expand description
A multi-level recursive PGM-Index.
This index builds multiple levels of linear models for efficient lookups. It does not own the data; the keys must be stored separately and passed to query methods.
Type Parameters
T: The value type that implementsIndexable. The index internally stores segments ofT::Keyfor the linear models.
Example
use pgm_extra::index::external::Static;
let keys: Vec<u64> = (0..10000).collect();
let index = Static::new(&keys, 64, 4).unwrap();
assert!(index.contains(&keys, &5000));
assert_eq!(index.lower_bound(&keys, &5000), 5000);Implementations
Sourceimpl<T: Indexable> Static<T>
impl<T: Indexable> Static<T>
pub fn new_parallel( data: &[T], epsilon: usize, epsilon_recursive: usize, ) -> Result<Self, Error>
Sourcepub fn search_by_key(&self, key: &T::Key) -> ApproxPos
pub fn search_by_key(&self, key: &T::Key) -> ApproxPos
Get an approximate position for the given key.
Sourcepub fn lower_bound(&self, data: &[T], value: &T) -> usizewhere
T: Ord,
pub fn lower_bound(&self, data: &[T], value: &T) -> usizewhere
T: Ord,
Find the first position where data[pos] >= value.
Sourcepub fn upper_bound(&self, data: &[T], value: &T) -> usizewhere
T: Ord,
pub fn upper_bound(&self, data: &[T], value: &T) -> usizewhere
T: Ord,
Find the first position where data[pos] > value.
Sourcepub fn contains(&self, data: &[T], value: &T) -> boolwhere
T: Ord,
pub fn contains(&self, data: &[T], value: &T) -> boolwhere
T: Ord,
Check if the value exists in the data.
pub fn is_empty(&self) -> bool
Sourcepub fn segments_count(&self) -> usize
pub fn segments_count(&self) -> usize
Number of segments across all levels.
pub fn epsilon(&self) -> usize
pub fn epsilon_recursive(&self) -> usize
Sourcepub fn size_in_bytes(&self) -> usize
pub fn size_in_bytes(&self) -> usize
Approximate memory usage in bytes.
Sourcepub fn range_indices<R>(&self, data: &[T], range: R) -> (usize, usize)where
T: Ord,
R: RangeBounds<T>,
pub fn range_indices<R>(&self, data: &[T], range: R) -> (usize, usize)where
T: Ord,
R: RangeBounds<T>,
Returns the (start, end) indices for iterating over data in the given range.
Sourcepub fn range<'a, R>(
&self,
data: &'a [T],
range: R,
) -> impl DoubleEndedIterator<Item = &'a T>where
T: Ord,
R: RangeBounds<T>,
pub fn range<'a, R>(
&self,
data: &'a [T],
range: R,
) -> impl DoubleEndedIterator<Item = &'a T>where
T: Ord,
R: RangeBounds<T>,
Returns an iterator over data in the given range.