Support for bytes and string keys via prefix extraction.
PGM-Index internally uses numeric keys for its linear models. For bytes/strings, we extract an 8-byte prefix as a u64 for the model, while keeping the full key for exact comparisons.
Structs
- Archived
Prefix - An archived
Prefix - Prefix
- A fixed-size prefix extracted from bytes/strings for use as a PGM key.
- Prefix
Resolver - The resolver for an archived
Prefix