Module range

Module range 

Functions

end_bound_to_idx
Convert an end bound to an index using lower_bound/upper_bound.
range_to_indices
Compute the (start, end) indices for a range.
start_bound_to_idx
Convert a start bound to an index using lower_bound/upper_bound.