Module range
pgm_
extra
1.2.0
Module range
Module Items
Functions
In pgm_
extra::
util
pgm_extra
::
util
Module
range
Functions

end_
bound_
to_
idx
Convert an end bound to an index using lower_bound/upper_bound.
range_
to_
indices
Compute the (start, end) indices for a range.
start_
bound_
to_
idx
Convert a start bound to an index using lower_bound/upper_bound.